==> Ver%203.0.0.zip: Ver 3.0.0/src/jp/mosp/payroll/action/AttendanceExportCardAction.java <==
/*
 * MosP - Mind Open Source Project         http://www.mosp.jp/
 * Copyright (C) 1987-2008 MIND Co., Ltd.  http://www.e-mind.co.jp/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package jp.mosp.payroll.action;

import java.util.Date;

import jp.mosp.common.CommonConst;
import jp.mosp.common.action.MosPAction;
import jp.mosp.common.common.MospConst;
import jp.mosp.common.common.MospException;
import jp.mosp.common.common.MospUtility;

import jp.mosp.payroll.vo.AttendanceExportCardVo;

public class AttendanceExportCardAction extends MosPAction {

	// R}h
	private static final String CMD_EXPORT_CARD_SHOW = "P1050";

	/**
	 * RXgN^
	 */
	public AttendanceExportCardAction() {
		super();
	}

	/**
	 * ANV
	 */
	public void action() throws Exception {
		// DBRlNV擾
		getConnection();
		// PAYROLLmF
		confirmPayrollAuth();
		// VO̎擾
		AttendanceExportCardVo vo = getInitVo();
		init(vo);
		// R}h̏
		if (cmd.equals(CMD_EXPORT_CARD_SHOW)) {
			// \			
			show(vo);
		} else {
			throw new MospException(MospConst.EX_CMD_INVALID);
		}
	}

	protected AttendanceExportCardVo getInitVo() {
		AttendanceExportCardVo vo = null;
		Object obj = session.getAttribute(MospConst.ATT_FORMER_VO);
		if (obj instanceof AttendanceExportCardVo) {
			vo = (AttendanceExportCardVo)obj;
		} else {
			vo = new AttendanceExportCardVo();
		}	
		return vo;
	}

	/**
	 * 
	 * @param vo			ΏVO
	 * @throws Exception
	 */
	protected void init(AttendanceExportCardVo vo) throws Exception {
		vo.clearMessage();
		vo.clearErrField();
		vo.initVo(cfg, msg, cmd, aspUser, user);
		// VOyуtH[hURL̐ݒ
		setVo(vo);
		setUrl(vo.getRetUrl());
		session.setAttribute(MospConst.ATT_FORMER_VO, vo);
		// [U[擾
		getInfo(user.getUserId());
		// v_E擾
		if (hasCalculateAuth()) {
			vo.aryPltSection = util.addArrayFirstRowValue(
					getSectionArrayAll(), 
					CommonConst.NAM_COMMON_STRING_INITIAL_VALUE,
					CommonConst.NAM_ALL_SECTION
			);
		} else {
			vo.aryPltSection = getSectionArrayForManager();
		}
		// NxXg擾
		vo.aryPltYear = util.getYearArray(MospUtility.getYear(getCalcMonth()), 1, 1);
		// Xg擾
		vo.aryPltMonth = util.getMonthArray();
	}

	/**
	 * \
	 * @param vo			ΏVO
	 * @throws Exception
	 */
	protected void show(AttendanceExportCardVo vo) throws Exception {
		// ΑӌvZΏ۔N擾
		Date current = getCalcMonth();
		vo.setPltYear(String.valueOf(MospUtility.getYear(current)));
		vo.setPltMonth(String.valueOf(MospUtility.getMonth(current)));
		vo.setPltSection(mKihon.getSCode());
	}

}

==> Ver%203.1.1.zip: Ver 3.1.1/src/jp/mosp/payroll/action/AttendanceExportCardAction.java <==
/*
 * MosP - Mind Open Source Project         http://www.mosp.jp/
 * Copyright (C) 1987-2009 MIND Co., Ltd.  http://www.e-mind.co.jp/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package jp.mosp.payroll.action;

import java.util.Date;

import jp.mosp.common.CommonConst;
import jp.mosp.common.MosPAction;
import jp.mosp.common.common.MospConst;
import jp.mosp.common.common.MospException;
import jp.mosp.common.common.MospUtility;

import jp.mosp.payroll.vo.AttendanceExportCardVo;

public class AttendanceExportCardAction extends MosPAction {

	// R}h
	private static final String CMD_EXPORT_CARD_SHOW = "P1050";

	/**
	 * RXgN^
	 */
	public AttendanceExportCardAction() {
		super();
	}

	/**
	 * ANV
	 */
	public void action() throws Exception {
		// DBRlNV擾
		getConnection();
		// PAYROLLmF
		confirmPayrollAuth();
		// VO̎擾
		AttendanceExportCardVo vo = getInitVo();
		init(vo);
		// R}h̏
		if (cmd.equals(CMD_EXPORT_CARD_SHOW)) {
			// \			
			show(vo);
		} else {
			throw new MospException(MospConst.EX_CMD_INVALID);
		}
	}

	protected AttendanceExportCardVo getInitVo() {
		AttendanceExportCardVo vo = null;
		Object obj = session.getAttribute(MospConst.ATT_FORMER_VO);
		if (obj instanceof AttendanceExportCardVo) {
			vo = (AttendanceExportCardVo)obj;
		} else {
			vo = new AttendanceExportCardVo();
		}	
		return vo;
	}

	/**
	 * 
	 * @param vo			ΏVO
	 * @throws Exception
	 */
	protected void init(AttendanceExportCardVo vo) throws Exception {
		vo.clearMessage();
		vo.clearErrField();
		vo.initVo(cfg, msg, cmd, aspUser, user);
		// VOyуtH[hURL̐ݒ
		setVo(vo);
		setUrl(vo.getRetUrl());
		session.setAttribute(MospConst.ATT_FORMER_VO, vo);
		// [U[擾
		getInfo(user.getUserId());
		// v_E擾
		if (hasCalculateAuth()) {
			vo.aryPltSection = util.addArrayFirstRowValue(
					getSectionArrayAll(), 
					CommonConst.NAM_COMMON_STRING_INITIAL_VALUE,
					CommonConst.NAM_ALL_SECTION
			);
		} else {
			vo.aryPltSection = getSectionArrayForManager();
		}
		// NxXg擾
		vo.aryPltYear = util.getYearArray(MospUtility.getYear(getCalcMonth()), 1, 1);
		// Xg擾
		vo.aryPltMonth = util.getMonthArray();
	}

	/**
	 * \
	 * @param vo			ΏVO
	 * @throws Exception
	 */
	protected void show(AttendanceExportCardVo vo) throws Exception {
		// ΑӌvZΏ۔N擾
		Date current = getCalcMonth();
		vo.setPltYear(String.valueOf(MospUtility.getYear(current)));
		vo.setPltMonth(String.valueOf(MospUtility.getMonth(current)));
		vo.setPltSection(mKihon.getSCode());
	}

}
